@@ -178,10 +178,10 @@ void move_selection (gpointer direction_pointer)
             gtk_tree_store_move_before (ks.treestore, &ks.iter, NULL);
     }
 
-    push_new_item_on_undo_stack (NOT_AFTER_SAVE); // First update undo stack so ...
+    push_new_item_on_undo_stack (NOT_AFTER_SAVE_UNDER_NEW_FILE_NAME); // First update undo stack so ...
     activate_change_done ();
-    row_selected ();                              /* ... the toolbar buttons and 
-                                                     application menu's undo/redo items get the correct sensitivity settings. */
+    row_selected ();                                                  /* ... the toolbar buttons and 
+                                                                         application menu's undo/redo items get the correct sensitivity settings. */
 }
 
 /* 
@@ -336,10 +336,10 @@ void visualize_menus_items_and_separators (gpointer recursively_pointer)
         gtk_tree_path_free ((GtkTreePath *) filter_visualization[ED_FILTER_SELECTED_PATH]);
     }
 
-    push_new_item_on_undo_stack (NOT_AFTER_SAVE); // First update undo stack so ...
+    push_new_item_on_undo_stack (NOT_AFTER_SAVE_UNDER_NEW_FILE_NAME); // First update undo stack so ...
     activate_change_done ();
-    row_selected ();                              /* ... the toolbar buttons and 
-                                                     application menu's undo/redo items get the correct sensitivity settings. */
+    row_selected ();                                                  /* ... the toolbar buttons and 
+                                                                         application menu's undo/redo items get the correct sensitivity settings. */
 
 #if !(GLIB_CHECK_VERSION(2,56,0))
     // Cleanup
@@ -418,10 +418,10 @@ void icon_choosing_by_button_or_context_menu (void)
     // The icon was not chosen during the creation of a new element, so this must be recorded internally as a change that has been applied.
     // The icon hasn't been chosen during the addition of a new (pipe) menu or item, so changes have been applied.
     if (!gtk_widget_get_visible (ks.enter_values_box)) {
-        push_new_item_on_undo_stack (NOT_AFTER_SAVE); // First update undo stack so ...
+        push_new_item_on_undo_stack (NOT_AFTER_SAVE_UNDER_NEW_FILE_NAME); // First update undo stack so ...
         activate_change_done ();
-        row_selected ();                              /* ... the toolbar buttons and 
-                                                         application menu's undo/redo items get the correct sensitivity settings. */
+        row_selected ();                                                  /* ... the toolbar buttons and 
+                                                                             application menu's undo/redo items get the correct sensitivity settings. */
     }
 }
 
@@ -550,11 +550,11 @@ void remove_icons_from_menus_or_items (gpointer push_on_undo_stack)
     }
 
     if (GPOINTER_TO_UINT (push_on_undo_stack)) {
-        push_new_item_on_undo_stack (NOT_AFTER_SAVE); // First update undo stack so ...
+        push_new_item_on_undo_stack (NOT_AFTER_SAVE_UNDER_NEW_FILE_NAME); // First update undo stack so ...
     }
     activate_change_done ();
-    row_selected ();                         /* ... the toolbar buttons and 
-                                                    application menu's undo/redo items get the correct sensitivity settings. */
+    row_selected ();                                                      /* ... the toolbar buttons and 
+                                                                             application menu's undo/redo items get the correct sensitivity settings. */
 
 #if !(GLIB_CHECK_VERSION(2,56,0))
     // Cleanup
@@ -593,7 +593,10 @@ void change_row (gpointer changed_entry_field_ptr)
             txt_field_to_compare = ks.txt_fields[EXECUTE_TXT];
     }
 
-    // Do not continue if the new value equals the old value.
+    /* Do not continue if the new value equals the old value.
+       Pressing Enter in an empty entry field results in txt_field_to_compare 
+       being NULL, since it’s assigned from the corresponding ks.txt_fields 
+       element, which is NULL for empty fields. */
     if (STREQ (entry_txt[changed_entry_field], txt_field_to_compare) || 
         (!(*entry_txt[changed_entry_field]) && !txt_field_to_compare)) {
         return;
@@ -652,10 +655,10 @@ void change_row (gpointer changed_entry_field_ptr)
         gtk_tree_store_set (ks.treestore, &ks.iter, TS_VALUE, entry_txt[MENU_ELEMENT_OR_VALUE_ENTRY], -1);
     }
 
-    push_new_item_on_undo_stack (NOT_AFTER_SAVE); // First update undo stack so ...
+    push_new_item_on_undo_stack (NOT_AFTER_SAVE_UNDER_NEW_FILE_NAME); // First update undo stack so ...
     activate_change_done ();
-    row_selected ();                              /* ... the toolbar buttons and 
-                                                     application menu's undo/redo items get the correct sensitivity settings. */
+    row_selected ();                                                  /* ... the toolbar buttons and 
+                                                                         application menu's undo/redo items get the correct sensitivity settings. */
 }
 
 /* 
@@ -723,10 +726,10 @@ void cell_edited (G_GNUC_UNUSED       GtkCellRendererText *renderer,
         set_entry_fields ();
     }
 
-    push_new_item_on_undo_stack (NOT_AFTER_SAVE); // First update undo stack so ...
+    push_new_item_on_undo_stack (NOT_AFTER_SAVE_UNDER_NEW_FILE_NAME); // First update undo stack so ...
     activate_change_done ();
-    row_selected ();                              /* ... the toolbar buttons and 
-                                                     application menu's undo/redo items get the correct sensitivity settings. */
+    row_selected ();                                                  /* ... the toolbar buttons and 
+                                                                         application menu's undo/redo items get the correct sensitivity settings. */
 }
                                                                         
 /*
@@ -962,8 +965,8 @@ void boolean_toggled (void)
     gtk_tree_store_set (GTK_TREE_STORE (ks.ts_model), &ks.iter, TS_VALUE, 
                         (STREQ (ks.txt_fields[VALUE_TXT], "yes")) ? "no" : "yes", -1);
 
-    push_new_item_on_undo_stack (NOT_AFTER_SAVE); // First update undo stack so ...
+    push_new_item_on_undo_stack (NOT_AFTER_SAVE_UNDER_NEW_FILE_NAME); // First update undo stack so ...
     activate_change_done ();
-    row_selected ();                              /* ... the toolbar buttons and 
-                                                     application menu's undo/redo items get the correct sensitivity settings. */
+    row_selected ();                                                  /* ... the toolbar buttons and 
+                                                                         application menu's undo/redo items get the correct sensitivity settings. */
 }
