@@ -19,7 +19,7 @@
 
 #include <gtk/gtk.h>
 
-#include <string.h> // Sometimes this might have to be included explicitly.
+#include <string.h> // May need to be included explicitly in some environments.
 
 #include "declarations_definitions_and_enumerations.h"
 #include "selecting.h"
@@ -33,7 +33,7 @@ static gboolean check_for_selected_dsct (              GtkTreeModel *filter_mode
 
 /* 
 
-    Displays a message if all options for execute or startupnotify have been set.
+    Displays a message if all options for "execute" or "startupnotify" have been set.
 
 */
 
@@ -47,7 +47,7 @@ static void all_options_have_been_set_msg (const gchar *msg_label_txt)
 
 /* 
 
-    Checks if a selected node has a descendant that has also been selected.
+    Checks whether a selected node has a descendant that is also selected.
 
 */
 
@@ -57,7 +57,7 @@ static gboolean check_for_selected_dsct (              GtkTreeModel *filter_mode
                                                        gboolean     *selected_row_has_selected_dsct)
 {
     GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (ks.treeview));
-    // The path of the model, not filter model, is needed to check whether the row is selected.
+    // The path of the underlying model, not the filter model, is needed to check whether the row is selected.
     g_autoptr(GtkTreePath) model_path = gtk_tree_model_filter_convert_path_to_child_path ((GtkTreeModelFilter *) filter_model, 
                                                                                           filter_path);
 
@@ -65,16 +65,17 @@ static gboolean check_for_selected_dsct (              GtkTreeModel *filter_mode
         *selected_row_has_selected_dsct = TRUE;
     }
 
-    return *selected_row_has_selected_dsct; // Stop iteration if a selected descendant has been found.
+    return *selected_row_has_selected_dsct; // Stop iteration if a selected descendant is found.
 }
 
 /* 
 
-    If one or more rows have been selected, all (in)appropriate actions for them are (de)activated according to 
-    criteria as e.g. their type (menu, item, etc.), expansion and visibility status, position, and the number of 
-    selected rows.
-    If there is currently no selected row left after an unselection, 
-    all actions that would be eligible in case of a selection are deactivated.
+    If one or more rows are selected, all applicable or inapplicable actions for them 
+    are activated or deactivated based on criteria such as their type (menu, item, etc.), 
+    expansion and visibility status, position, and the number of selected rows.
+
+    If no rows remain selected after an unselection, all actions that would otherwise 
+    be available in the case of a selection are deactivated.
 
 */
 
@@ -88,9 +89,9 @@ void row_selected (void)
     GList *selected_rows = gtk_tree_selection_get_selected_rows (selection, &ks.ts_model);
 #endif
 
-    gboolean dragging_enabled = TRUE; // Default
+    gboolean dragging_enabled = TRUE; // Default value.
 
-    // Defaults
+    // Default values.
     gboolean at_least_one_selected_row_has_no_children = FALSE;
     gboolean at_least_one_descendant_is_invisible = FALSE;
 
@@ -118,7 +119,7 @@ void row_selected (void)
 
     // Check if dragging has to be blocked.
     if (number_of_selected_rows > 1) {
-        // Defaults
+        // Default values.
         gboolean selected_row_has_selected_dsct = FALSE;
         gboolean menu_pipemenu_item_separator_selected = FALSE;
         gboolean at_least_one_prompt_command_startupnotify_selected = FALSE;
@@ -178,7 +179,7 @@ void row_selected (void)
             (action_selected && option_selected) || 
             (at_least_one_prompt_command_startupnotify_selected && at_least_one_enabled_name_wmclass_icon_selected) || 
             at_least_one_option_more_than_once_selected || 
-            selected_row_has_selected_dsct) { // Dragging is blocked
+            selected_row_has_selected_dsct) { // Dragging is blocked.
             g_autoptr(GString) statusbar_msg = g_string_new (NULL);
 
             dragging_enabled = FALSE;
@@ -189,17 +190,17 @@ void row_selected (void)
                 g_string_append (statusbar_msg, _("Action and option selected   "));
             }
             if (at_least_one_prompt_command_startupnotify_selected && at_least_one_enabled_name_wmclass_icon_selected) {
-				// Translation note: Do not translate "startupnotify"
+				// Translation note: Do not translate the word "startupnotify".
                 g_string_append (statusbar_msg, _("Action option and startupnotify option selected   "));
             }
             if (at_least_one_option_more_than_once_selected) {
                 g_string_append (statusbar_msg, _("More than one option of a kind selected   "));
             }
-            // This message is only shown if the other cases don't apply.
+            // This message is only shown if none of the other cases apply.
             if (!(*statusbar_msg->str)) { // -> selected_row_has_selected_dsct = TRUE
                 g_string_append (statusbar_msg, _("Row and descendant of it selected   "));
             }
-            // Translation note: This refers to a drag and drop operation
+            // Translation note: This refers to a drag-and-drop operation.
             g_string_prepend (statusbar_msg, _("Dragging disabled --- "));
             show_msg_in_statusbar (statusbar_msg->str);
 
@@ -210,8 +211,8 @@ void row_selected (void)
 
     if (dragging_enabled) {
         /*
-            Create a list of row references of the selected paths for possible later drag and drop usage.
-            An existing list is cleared first.
+            Create a list of row references for the selected paths, for possible later use 
+            in drag-and-drop operations. Any existing list is cleared first.
         */
 #if GLIB_CHECK_VERSION(2,64,0)
         g_clear_slist (&ks.source_paths, (GDestroyNotify) gtk_tree_row_reference_free);
@@ -225,7 +226,7 @@ void row_selected (void)
         ks.source_paths = g_slist_reverse (ks.source_paths);
     }
 
-    // Default settings
+    // Default settings.
 
     if (gtk_widget_get_visible (ks.action_option_grid) || gtk_widget_get_visible (ks.enter_values_box)) {
         if (gtk_widget_get_visible (ks.action_option_grid)) {
@@ -249,8 +250,11 @@ void row_selected (void)
                 if (gtk_style_context_has_class (context, "double_menu_ID")) {
                     gtk_style_context_remove_class (context, "double_menu_ID");
                 }
-                /* This if statement is necessary, since row_selected() is called at startup, 
-                   when ks.enter_values_box is still visible, but the signal for ks.entry_fields[MENU_ID_ENTRY] not yet connected. */
+                /* 
+                  This "if" statement is necessary because row_selected() is called at startup, 
+                  when ks.enter_values_box is still visible but the signal for ks.entry_fields[MENU_ID_ENTRY] 
+                  has not yet been connected.
+                */
                 if (g_signal_handler_is_connected (ks.entry_fields[MENU_ID_ENTRY], ks.handler_id_double_menu_id)) {
                     g_signal_handler_disconnect (ks.entry_fields[MENU_ID_ENTRY], ks.handler_id_double_menu_id);
                 }
@@ -272,7 +276,8 @@ void row_selected (void)
             gtk_widget_show (ks.new_action_option_widgets[ACTION_OPTION_DONE]);
             gtk_widget_show (ks.new_action_option_widgets[ACTION_OPTION_CANCEL]);
             gtk_widget_show (ks.remove_icon);
-            // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Menu ID”), not the definite one (“The Menu ID”).
+            // Translation note: If the target language distinguishes between definite and indefinite forms, 
+            // please use the indefinite form (“Menu ID”), not the definite one (“The Menu ID”).
             gtk_label_set_markup (GTK_LABEL (ks.entry_labels[MENU_ID_ENTRY]), _(" Menu ID: "));
             gtk_widget_hide (ks.mandatory);
             gtk_label_set_markup (GTK_LABEL (ks.mandatory), ks.mandatory_label_txt->str);
@@ -296,7 +301,7 @@ void row_selected (void)
         g_action_map_remove_action (G_ACTION_MAP (ks.app), "visualize");
     }
     else {
-        // Defaults
+        // Default settings.
         gtk_widget_set_sensitive (ks.MBar_menu_items[EDIT_MENU], TRUE);
         gtk_widget_set_sensitive (ks.MBar_menu_items[SEARCH_MENU], TRUE);
         gtk_widget_set_sensitive (ks.MBar_menu_items[OPTIONS_MENU], TRUE);
@@ -338,7 +343,7 @@ void row_selected (void)
     gtk_widget_set_sensitive (ks.tb_buttons[TB_BUTTON_NEW], (!treestore_is_empty || ks.change_done));
     gtk_widget_set_sensitive (ks.tb_buttons[TB_BUTTON_SAVE], (ks.filename && ks.change_done));
 
-    // Translation note: For a tooltip
+    // Translation note: Tooltip.
     g_autoptr(GString) save_menu_tooltip = g_string_new (_("Save Menu"));
     if (G_UNLIKELY (ks.pos_inside_undo_stack == 1 && ks.number_of_undo_stack_items == 1)) {
         gboolean edit_done_during_loading = (ks.loading_process_edit_types[ICON_INFO_CORRECTED] || 
@@ -351,9 +356,9 @@ void row_selected (void)
 
         gchar *save_menu_tooltip_txts[] = { N_("At least one incorrect icon path or format has been corrected"), 
                                             N_("At least one incorrect option value has been corrected"), 
-											// Translation note: "Visualize" in the sense of making something visible
+											// Translation note: "Visualize" in the sense of making something visible.
                                             N_("At least one invisible menu element has been visualized or removed"), 
-											// Translation note: Do not translate "execute"
+											// Translation note: Do not translate the word "execute".
                                             N_("At least one \"execute\" option has been converted") };
 
         for (corrections_cnt = 0; corrections_cnt < NUMBER_OF_LOADING_PROCESS_EDIT_TYPES; ++corrections_cnt) {
@@ -412,8 +417,8 @@ void row_selected (void)
 
     if (ks.settings.show_menu_button) {
         /*
-            If there has been an error during the creation of the initial undo item stack file, 
-            ks.pos_inside_undo_stack will remain set to 0.
+            If there is an error during creation of the initial undo item stack file,
+            ks.pos_inside_undo_stack remains set to 0.
         */
         if (ks.pos_inside_undo_stack > 1) {
             g_action_map_add_action (G_ACTION_MAP (ks.app), G_ACTION (ks.edit_actions[M_UNDO]));
@@ -456,8 +461,8 @@ void row_selected (void)
     }
     else {
         /*
-            If there has been an error during the creation of the initial undo item stack file, 
-            ks.pos_inside_undo_stack will remain set to 0.
+            If there is an error during creation of the initial undo item stack file,
+            ks.pos_inside_undo_stack remains set to 0.
         */
         gtk_widget_set_sensitive (ks.MBar_edit_menu_items[M_UNDO], (ks.pos_inside_undo_stack > 1));
         gtk_widget_set_sensitive (ks.MBar_edit_menu_items[M_REDO], (ks.pos_inside_undo_stack < ks.number_of_undo_stack_items));
@@ -475,7 +480,7 @@ void row_selected (void)
 
     set_status_of_expand_and_collapse_buttons_and_menu_items ();
 
-    // Show/activate or hide/deactivate certain widgets depending on if there is no or more than one selection.
+    // Show/activate or hide/deactivate certain widgets depending on whether there is no selection or more than one selection.
     if (number_of_selected_rows != 1) {
         free_elements_of_static_string_array (ks.txt_fields, NUMBER_OF_TXT_FIELDS, TRUE);
         FOREACH_IN_ARRAY (ks.bt_movements, buttons_cnt) {
@@ -534,8 +539,8 @@ void row_selected (void)
     GtkTreePath *path = selected_rows->data;
     const gint path_depth = gtk_tree_path_get_depth (path);
     GtkTreeIter parent;
-    g_autofree gchar *menu_element_txt_parent = NULL; // Default
-    const gchar *preset_choice = NULL; // Default
+    g_autofree gchar *menu_element_txt_parent = NULL; // Default value.
+    const gchar *preset_choice = NULL; // Default value.
 
     gtk_tree_model_get_iter (ks.ts_model, &ks.iter, path);
 
@@ -577,12 +582,13 @@ void row_selected (void)
     gtk_widget_set_sensitive (ks.bt_movements[MOVE_DOWN], (not_at_bottom && !option_and_autosort));
     gtk_widget_set_sensitive (ks.bt_movements[MOVE_BOTTOM], (not_at_bottom && !option_and_autosort));
 
-    set_forward_and_back_buttons_of_find_grid (); // Can't be done in the beginning, since the iterator as not been set yet.
+    set_forward_and_back_buttons_of_find_grid (); // Can't be done at the beginning, since the iterator has not yet been set.
 
     // Item selected?
     if (STREQ (ks.txt_fields[TYPE_TXT], "item")) {
         gtk_widget_show (ks.bt_add[ACTION_OR_OPTION]);
-        // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Action”), not the definite one (“The Action”).
+        // Translation note: If the target language distinguishes between definite and indefinite forms, 
+        // please use the indefinite form (“Action”), not the definite one (“The Action”).
         gtk_label_set_text_with_mnemonic (GTK_LABEL (ks.bt_add_action_option_label), _("_Action"));
     }
 
@@ -591,7 +597,7 @@ void row_selected (void)
         const gint number_of_children_of_parent = gtk_tree_model_iter_n_children (ks.ts_model, &parent);
         const gint number_of_children_of_iter = gtk_tree_model_iter_n_children (ks.ts_model, &ks.iter);
 
-        // Defaults
+        // Default value.
         gboolean prompt_or_command_selected_and_action_is_Execute = FALSE;
         gboolean startupnotify_or_option_of_it_selected = FALSE;
 
@@ -607,9 +613,11 @@ void row_selected (void)
                                                ((STREQ (ks.txt_fields[MENU_ELEMENT_TXT], "Execute") &&
                                                number_of_children_of_iter < NUMBER_OF_EXECUTE_OPTS) || 
                                                number_of_children_of_iter == 0)) ? 
-                                              // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Action/Option”), not the definite one (“The Action/The Option”).
+                                              // Translation note: If the target language distinguishes between definite and indefinite forms, 
+                                              // please use the indefinite form (“Action/Option”), not the definite one (“The Action/The Option”).
                                               _("_Action/Option") : 
-                                              // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Action”), not the definite one (“The Action”).
+                                              // Translation note: If the target language distinguishes between definite and indefinite forms, 
+                                              // please use the indefinite form (“Action”), not the definite one (“The Action”).
                                               _("_Action"));
         }
 
@@ -628,7 +636,8 @@ void row_selected (void)
 
         // Default button text for a selected option
         if (prompt_or_command_selected_and_action_is_Execute || startupnotify_or_option_of_it_selected) {
-            // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Option”), not the definite one (“The Option”).
+            // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, 
+            // please use the indefinite form (“Option”), not the definite one (“The Option”).
             gtk_label_set_text_with_mnemonic (GTK_LABEL (ks.bt_add_action_option_label), _("O_ption"));
         }
 
@@ -636,17 +645,17 @@ void row_selected (void)
             (STREQ (ks.txt_fields[TYPE_TXT], "option block") && number_of_children_of_iter == NUMBER_OF_STARTUPNOTIFY_OPTS)) {
             // All options of "Execute" are set.
             if (number_of_children_of_parent == NUMBER_OF_EXECUTE_OPTS) {
-				// Translation note: Do not translate "Execute"
+				// Translation note: Do not translate the word "Execute".
                 all_options_have_been_set_msg (_(" All Options for This Execute Action Have Been Set"));
             }
             // One option of "Execute" is not set.
             else if (number_of_children_of_parent == NUMBER_OF_EXECUTE_OPTS - 1) {
                 gboolean execute_options_status[NUMBER_OF_EXECUTE_OPTS] = { 0 };
-                const gchar *execute_opts_with_mnemonic[] = { // Translation note: Do not translate
+                const gchar *execute_opts_with_mnemonic[] = { // Translation note: Do not translate this.
 				                                              N_("_Prompt"),
-															  // Translation note: Do not translate
+															  // Translation note: Do not translate this.
 				                                              N_("_Command"), 
-															  // Translation note: Do not translate
+															  // Translation note: Do not translate this.
 															  _("Startup_notify") };
 
                 check_for_existing_options (&parent, NUMBER_OF_EXECUTE_OPTS, ks.execute_options, execute_options_status);
@@ -670,7 +679,7 @@ void row_selected (void)
                 number_of_children_of_parent == NUMBER_OF_EXECUTE_OPTS) || 
                 (STREQ (ks.txt_fields[TYPE_TXT], "option") && 
                 number_of_children_of_parent == NUMBER_OF_STARTUPNOTIFY_OPTS)) {
-				// Translation note: Do not translate "Startupnotify"
+				// Translation note: Do not translate the word "Startupnotify".
                 all_options_have_been_set_msg (_(" All Options for This Startupnotify Option Block Have Been Set"));
             }
             // "startupnotify" option block or option of it selected and one option of "startupnotify" not set.
@@ -680,13 +689,13 @@ void row_selected (void)
                      (STREQ (ks.txt_fields[TYPE_TXT], "option") && 
                      number_of_children_of_parent == NUMBER_OF_STARTUPNOTIFY_OPTS - 1)) {
                 gboolean startupnotify_options_status[NUMBER_OF_STARTUPNOTIFY_OPTS] = { 0 };
-                const gchar *startupnotify_opts_with_mnemonic[] = { // Translation note: Do not translate
+                const gchar *startupnotify_opts_with_mnemonic[] = { // Translation note: Do not translate this.
 				                                                    N_("E_nabled"), 
-																	// Translation note: Do not translate
+																	// Translation note: Do not translate this.
 				                                                    N_("_Name"), 
-																	// Translation note: Do not translate
+																	// Translation note: Do not translate this.
 																	N_("_WM__CLASS"), 
-																	// Translation note: Do not translate
+																	// Translation note: Do not translate this.
 																	N_("_Icon") };
 
                 if (STREQ (ks.txt_fields[TYPE_TXT], "option block")) {
@@ -709,23 +718,23 @@ void row_selected (void)
         }
 
         /*
-            "prompt" option selected and action is "Exit" or "SessionLogout" or
-            "command" option selected and action is "Restart".
+            "prompt" option selected with action "Exit" or "SessionLogout",
+            or "command" option selected with action "Restart".
         */
         if (STREQ (ks.txt_fields[TYPE_TXT], "option") && streq_any (ks.txt_fields[MENU_ELEMENT_TXT], "prompt", "command", NULL) && 
             streq_any (menu_element_txt_parent, "Exit", "Restart", "SessionLogout", NULL)) { 
             const gchar *msg_label_txt;
 
             if (STREQ (menu_element_txt_parent, "Exit")) {
-				// Translation note: Do not translate "Exit"
+				// Translation note: Do not translate the word "Exit".
                 msg_label_txt = _(" All Options for This Exit Action Have Been Set");
             }
             else if (STREQ (menu_element_txt_parent, "Restart")) {
-				// Translation note: Do not translate "Restart"
+				// Translation note: Do not translate the word "Restart".
                 msg_label_txt = _(" All Options for This Restart Action Have Been Set");
             }
             else { // SessionLogout
-			    // Translation note: Do not translate "SessionLogout"
+			    // Translation note: Do not translate the word "SessionLogout".
                 msg_label_txt = _(" All Options for This SessionLogout Action Have Been Set");
             }
 
@@ -756,8 +765,10 @@ void row_selected (void)
         set_entry_fields ();
     }
 
-    /* Set the correct treestore position argument for the changed signal of the menu_element_or_value entry.
-       It depends on whether the entry is for a menu element or for a value. */ 
+    /* 
+       Set the correct treestore position argument for the “changed” signal of the menu_element_or_value entry.
+       It depends on whether the entry is for a menu element or for a value.
+    */
     if (gtk_widget_get_visible (ks.entry_fields[MENU_ELEMENT_OR_VALUE_ENTRY])) {
         g_signal_handler_disconnect (ks.entry_fields[MENU_ELEMENT_OR_VALUE_ENTRY], ks.handler_id_entry_field_changed);
         ks.handler_id_entry_field_changed = g_signal_connect_swapped (ks.entry_fields[MENU_ELEMENT_OR_VALUE_ENTRY], "changed", 
@@ -766,7 +777,7 @@ void row_selected (void)
                                                                                         TS_MENU_ELEMENT : TS_VALUE));
     }
 
-    gtk_widget_queue_draw (ks.treeview); // Force redrawing of treeview.
+    gtk_widget_queue_draw (ks.treeview); // Force redrawing of the tree view.
 
 #if !(GLIB_CHECK_VERSION(2,56,0))
     // Cleanup
@@ -784,8 +795,8 @@ static gboolean avoid_overlapping (G_GNUC_UNUSED gpointer user_data)
 {
     g_autoptr(GtkTreePath) path;
 
-    // A row is supposed to be currently selected and thus it should be possible to retrieve a path;
-    // If for some reason it isn't possible to do so (anymore), do not attempt to scroll to that row.
+    // A row should currently be selected, so a path should be retrievable.
+    // If, for some reason, it is no longer possible, do not attempt to scroll to that row.
     if (G_LIKELY ((path = gtk_tree_model_get_path (ks.ts_model, &ks.iter)))) {
         // There is no horizontal move to a certain column (NULL). Row and column alignments (0,0) are not used (FALSE).
         gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (ks.treeview), path, NULL, FALSE, 0, 0);
@@ -806,8 +817,9 @@ void set_entry_fields (void)
 
     gtk_widget_show (ks.entry_grid);
 
-    // Default settings
-    // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Label”), not the definite one (“The Label”).
+    // Default settings.
+    // Translation note: If the target language distinguishes between definite and indefinite forms, 
+    // please use the indefinite form (“Label”), not the definite one (“The Label”).
     gtk_label_set_text (GTK_LABEL (ks.entry_labels[MENU_ELEMENT_OR_VALUE_ENTRY]), _(" Label: "));
 
     g_autofree gchar *execute_label_text = g_strdup_printf  ("%s Execute: ", right_to_left);
@@ -837,7 +849,7 @@ void set_entry_fields (void)
             gtk_widget_show (ks.entry_labels[ICON_PATH_ENTRY]);
             gtk_widget_show (ks.entry_fields[ICON_PATH_ENTRY]);
             gtk_widget_set_sensitive (ks.remove_icon, ks.txt_fields[ICON_PATH_TXT] != NULL);
-            if (ks.txt_fields[ICON_PATH_TXT]) { // No check for empty string necessary, as there can't be a path "".
+            if (ks.txt_fields[ICON_PATH_TXT]) { // No check for an empty string is necessary here, as the path cannot be "".
                 gtk_entry_set_text (GTK_ENTRY (ks.entry_fields[ICON_PATH_ENTRY]), ks.txt_fields[ICON_PATH_TXT]);
             }
 
@@ -882,7 +894,8 @@ void set_entry_fields (void)
             gtk_entry_set_text (GTK_ENTRY (ks.entry_fields[MENU_ELEMENT_OR_VALUE_ENTRY]), ks.txt_fields[VALUE_TXT]);
         }
     }
-
-    // If the last row is clicked, an overlapping of it by entry fields is avoided by this. No data is passed.
+    
+    // If the last row is clicked, this avoids it being overlapped by the entry fields.
+    // No data is passed.
     gdk_threads_add_idle ((GSourceFunc) avoid_overlapping, NULL);
 }
