@@ -131,7 +131,7 @@ static gboolean write_row_information (GtkTreeModel  *model,
 
 */
 
-void push_new_item_on_undo_stack (const gboolean after_save)
+void push_new_item_on_undo_stack (const gboolean after_save_under_new_file_name)
 {
     g_autoptr(GError) error = NULL;
 
@@ -164,7 +164,8 @@ void push_new_item_on_undo_stack (const gboolean after_save)
         ks.number_of_undo_stack_items = ks.pos_inside_undo_stack;
     }
 
-    if (!after_save) {
+    // The menu file has not been saved under a new name. Prepare to add a new undo stack item after the current position.
+    if (!after_save_under_new_file_name) {
         ks.pos_inside_undo_stack = ks.number_of_undo_stack_items + 1;
     }
 
@@ -173,25 +174,23 @@ void push_new_item_on_undo_stack (const gboolean after_save)
 
     g_autoptr(GOutputStream) undo_file_output_stream;
 
-    if (!after_save) {
-        if (G_UNLIKELY (!((undo_file_output_stream = G_OUTPUT_STREAM (g_file_create (compressed_undo_file, G_FILE_CREATE_NONE, 
-                                                                                     FALSE, &error)))))) {
-            show_errmsg_and_restore_position_index ("creation", error);
+    // The menu file has not been saved under a new name. Create a new undo stack item.
+    if (!after_save_under_new_file_name && G_UNLIKELY (!((undo_file_output_stream = G_OUTPUT_STREAM (g_file_create (compressed_undo_file, G_FILE_CREATE_NONE, 
+                                                                                                                    FALSE, &error)))))) {
+        show_errmsg_and_restore_position_index ("creation", error);
 
-            return;
-        }
+        return;
     }
-    else {
-        if (G_UNLIKELY (!((undo_file_output_stream = G_OUTPUT_STREAM (g_file_replace (compressed_undo_file, NULL, FALSE, 
-                                                                                      G_FILE_CREATE_NONE, NULL, &error)))))) {
-            g_autofree gchar *err_msg = g_strdup_printf (_("<b>Could not remove undo stack item</b> <tt>%1$i</tt> "
-                                                           "<b>inside tmp folder</b> <tt>%2$s</tt> <b>!\nError:</b> %3$s"), 
-                                                         ks.pos_inside_undo_stack, ks.tmp_path, error->message);
+    // The menu file has been saved under a new name. Replace the current undo stack item with one that includes the new file name.
+    else if (G_UNLIKELY (!((undo_file_output_stream = G_OUTPUT_STREAM (g_file_replace (compressed_undo_file, NULL, FALSE, 
+                                                                                       G_FILE_CREATE_NONE, NULL, &error)))))) {
+        g_autofree gchar *err_msg = g_strdup_printf (_("<b>Could not remove undo stack item</b> <tt>%1$i</tt> "
+                                                       "<b>inside tmp folder</b> <tt>%2$s</tt> <b>!\nError:</b> %3$s"), 
+                                                     ks.pos_inside_undo_stack, ks.tmp_path, error->message);
 
-            show_errmsg (err_msg);
+        show_errmsg (err_msg);
 
-            return;
-        }
+        return;
     }
 
     g_autoptr(GConverter) compressor = G_CONVERTER (g_zlib_compressor_new (G_ZLIB_COMPRESSOR_FORMAT_RAW, -1));
@@ -228,7 +227,7 @@ void push_new_item_on_undo_stack (const gboolean after_save)
     }
 
     // There has been an error, do not increase ks.number_of_undo_stack_items.
-    if (G_UNLIKELY (!after_save && ks.pos_inside_undo_stack == ks.number_of_undo_stack_items)) {
+    if (G_UNLIKELY (!after_save_under_new_file_name && ks.pos_inside_undo_stack == ks.number_of_undo_stack_items)) {
         return;
     }
 
@@ -457,7 +456,25 @@ void undo_redo_restore (const gchar *action)
     g_slist_free_full (selected_paths, (GDestroyNotify) gtk_tree_path_free);
 #endif
 
-    if (G_UNLIKELY (error)) {
+    if (G_LIKELY (!error)) {
+        // If this was a restore of an autosave, setting ks.pos_inside_undo_stack is done later when the first undo item is pushed on the stack.
+        if (!(STREQ (action, "restore"))) {
+            ks.pos_inside_undo_stack = new_pos_inside_undo_stack;
+            update_pos_inside_undo_stack_pointer ();
+            write_autosave (compressed_undo_file);
+        }
+
+        // If this was a restore of an autosave for a new menu that had not been saved yet, the ability to save (not save as) should be disabled.
+        if (STREQ (action, "restore") && !ks.filename) {
+            ks.restored_autosave_that_hasnt_been_saved_yet = TRUE;
+        }
+        
+        if (!(STREQ (action, "restore"))) {
+            ks.change_done = TRUE;
+        }
+        row_selected ();
+    }
+    else {
         g_autofree gchar *err_msg;
 
         if (!STREQ (action, "restore")) {
@@ -472,31 +489,12 @@ void undo_redo_restore (const gchar *action)
         }
 
         show_errmsg (err_msg);
-
-        return;
-    }
-
-    // If this was a restore of an autosave, setting ks.pos_inside_undo_stack is done later when the first undo item is pushed on the stack.
-    if (!(STREQ (action, "restore"))) {
-        ks.pos_inside_undo_stack = new_pos_inside_undo_stack;
-        update_pos_inside_undo_stack_pointer ();
-        write_autosave (compressed_undo_file);
-    }
-
-    // If this was a restore of an autosave for a new menu that had not been saved yet, the ability to save (not save as) should be disabled.
-    if (STREQ (action, "restore") && !ks.filename) {
-        ks.restored_autosave_that_hasnt_been_saved_yet = TRUE;
     }
 
     gtk_tree_model_foreach (ks.ts_model, (GtkTreeModelForeachFunc) add_icon_occurrence_to_list, NULL);
     if (ks.rows_with_icons) {
         ks.timeout_id = g_timeout_add_seconds (1, (GSourceFunc) check_for_external_file_and_settings_changes, "timeout");
     }
-
-    if (!(STREQ (action, "restore"))) {
-        ks.change_done = TRUE;
-    }
-    row_selected ();
 }
 
 /*
